ModuleManager

Struct ModuleManager 

pub struct ModuleManager {
    pub modules: Vec<EllieModule>,
}

Fields

modules: Vec<EllieModule>

Implementations

Source

impl ModuleManager

pub fn new() -> Self

pub fn find_module_by_item_hash( &mut self, hash: usize, ) -> Option<&mut EllieModule>

pub fn find_module_by_item_name( &mut self, name: &String, ) -> Option<&mut EllieModule>

pub fn register_module(&mut self, module: EllieModule)

pub fn get_module(&mut self, module_name: &str) -> Option<&mut EllieModule>

pub fn get_module_mut( &mut self, module_name: String, ) -> Option<&mut EllieModule>

pub fn add_native_call_trace( &mut self, trace: NativeCallTrace, ) -> Option<&'static str>

Register function to existing module items This function gets the native call trace from program and and matches with already registered native module functions. ## Params

Output
  • Option<usize> if the function is registered successfully it will return None, or else it will return the cause of the error